@@ -11,7 +11,7 @@ test_that("quick test with small arffs", {
     compareRWeka(INST_ARFF_DIR, "quotes_in_factor_levels.arff", data.reader = dreader)
     #compareRWeka(INST_ARFF_DIR, "many_types.arff", data.reader = dreader)
     compareRWeka(INST_ARFF_DIR, "dates.arff", data.reader = dreader)
-
+    compareRWeka(INST_ARFF_DIR, "check_logicals.arff", data.reader = dreader)
     expect_error(readARFF(path = paste(INST_ARFF_DIR, "dataset_1438_accelerometer.arff", sep = "/"), data.reader = dreader),
       "Type 'relational' currently not implemented.")
   }
@@ -28,5 +28,5 @@ test_that("writeARFF works as expected", {
 
   # delete colnames and try to write
   colnames(dat) = NULL
-  expect_error(writeARFF(dat, outfile, overwrite = TRUE), "Columns must be named")
+  expect_error(writeARFF(dat, outfile, overwrite = TRUE))
 })
